# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/tasks/actionable'
require 'role_management/actions'

module RoleManagement
  module Actions
    # Cleanup role documents and bindings related to an organization
    # that has been deleted.
    #
    # The input is an instance of `Platform::Tasks::Actionable::Context`
    # with an attribute `:crn` which is a `Platform::CRN::Organization`
    # object that identifies the organization that has been deleted.
    class OrganizationDeleted
      include ::Platform::Tasks::Actionable
      include Import['logger', 'role_management.stores.role_documents_directory']

      def call
        crn = context.crn

        logger.info { "Cleaning up role documents and bindings for org #{crn}" }
        role_documents_directory.delete_organization(org_crn: crn)
      end
    end
  end
end
