# frozen_string_literal: true

require 'import'
require 'graphql'

require 'cht-lib-fabric/tasks/actionable'

require 'role_management/models'

module RoleManagement
  module Actions
    class PermissionHierarchy
      include ::RoleManagement::Models::Privileges
      include Import['logger', 'role_management.stores.role_documents_directory']

      def call
        all_privs = all_privileges_struct
        permission_to_crn = role_documents_directory.permission_tuple_to_crn

        build_hierarchy(all_privs, permission_to_crn)
      end

      def build_hierarchy(priv_section_or_tuple, permission_to_crn)
        if priv_section_or_tuple.respond_to?(:children)
          permissions = []
          permission_groups = []
          priv_section_or_tuple.children.each do |child|
            item = build_hierarchy(child, permission_to_crn)
            next unless item
            if item.is_a?(::RoleManagement::Models::PermissionGroup)
              permission_groups << item
            else
              permissions << item
            end
          end
          # skip partner only permission groups for now
          return nil if priv_section_or_tuple.partner_only
          return ::RoleManagement::Models::PermissionGroup.new(
            groupName: priv_section_or_tuple.label,
            permissionGroup: permission_groups,
            permissions: permissions
          )
        else
          return to_permission(priv_section_or_tuple, permission_to_crn)
        end
      end

      def to_permission_group(label: nil, children: nil, permissions_arr: nil)
        ::RoleManagement::Models::PermissionGroup.new(
          groupName: priv_section.label,
          permissions: permission_arr,
          permissionGroup: children
        )
      end

      def to_permission(priv_tuple, permission_to_crn)
        id  = permission_to_crn[[priv_tuple.action, priv_tuple.subject]]
        if id
          ::RoleManagement::Models::Permission.new(
            id: permission_to_crn[[priv_tuple.action, priv_tuple.subject]],
            action: priv_tuple.action.to_s,
            subject: priv_tuple.subject.to_s,
            label: priv_tuple.label
          )
        else
          # happens if privilege file is more up-to-date then db permissions records
          # and we can resolve the id of the permission
          logger.warn("ID not found for tuple: #{priv_tuple.action}:#{priv_tuple.subject}")
          nil
        end
      end
    end
  end
end
