# frozen_string_literal: true

require 'import'
require 'graphql'
require 'dry-struct'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/crns/tenant'
require 'cht-lib-fabric/tasks/actionable'
require 'role_management/graphql/include_fields'

require 'role_management/actions'

module RoleManagement
  module Actions
    class RoleDocuments
      include ::RoleManagement::Actions::AuthorizationHelper
      include ::Platform::Helpers::GraphQL::RaiseError
      include Import['logger',
                     'role_management.stores.role_documents_directory',
                     'clients.authorization',
                     'role_management.helpers.flow_down_helper']

      def call (context, include_permissions:false)
        authorize!(subject: 'role_document', actions: 'read', context: context)

        customer_id = context[:request]&.current_customer
        customer_crn = ::Platform::CRNs::Tenant.new(customer: customer_id)
                                               .to_s

        organization_id = context[:request].current_organization

        sd_edges = role_documents_directory.system_defined(
          include_permissions: include_permissions
        )

        non_sd_edges = role_documents_directory.by_customer_crn(
          customer_crn,
          organization_id,
          include_permissions: include_permissions,
          service_account: service_account_caller?(context)
        )

        # Fetch shared role document ids
        shared_role_doc_ids = flow_down_helper.get_flow_down_items(type: 'role-document', context: context)

        logger.info "Shared Role Document Ids: #{shared_role_doc_ids}"

        shared_role_docs = role_documents_directory.by_shared_role_doc_id(
            customer_crn,
            shared_role_doc_ids,
            include_permissions: include_permissions
        ) unless shared_role_doc_ids.empty?

        shared_role_docs = [] if shared_role_docs.nil?

        logger.debug "Shared Role Documents [#{shared_role_docs}]"

        sd_edges + non_sd_edges + shared_role_docs
      end
    end
  end
end
