# frozen_string_literal: true

require 'import'
require 'graphql'
require 'dry-struct'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/crns/tenant'
require 'cht-lib-fabric/tasks/actionable'
require 'cht-lib-fabric/helpers/graphql/raise_error'

require 'role_management/actions'

module RoleManagement
  module Actions
    class UserGroupRoleBindings
      include ::Platform::Helpers::GraphQL::RaiseError
      include ::RoleManagement::Actions::AuthorizationHelper
      include Import['logger',
                     'role_management.stores.role_documents_directory',
                     'clients.authorization']

      def call (context, lookahead: nil)
        authorize!(subject: "role_binding", actions: "read", context:context)

        include_role_doc_permissions = false
        include_role_docs            = false
        include_role_bindings        = false

        unless lookahead.nil?
          include_role_doc_permissions = lookahead.selection(:edges).selection(:node).selection(:roleDocument).selects?(:permissions) ||
                                         lookahead.selection(:nodes).selection(:roleDocument).selects?(:permissions)
          include_role_docs            = lookahead.selection(:edges).selection(:node).selects?(:roleDocument) ||
                                         lookahead.selection(:nodes).selects?(:roleDocument)
          include_role_bindings = lookahead.selection(:edges).selection(:node).selection(:roleDocument).selects?(:userGroupRoleBindings) ||
                                  lookahead.selection(:nodes).selection(:roleDocument).selects?(:userGroupRoleBindings)
        end

        customer_id = context[:request]&.current_customer
        customer_crn = ::Platform::CRNs::Tenant.new(customer: customer_id)
        current_org_crn = ::Platform::CRNs::Organization.new(
          customer: customer_id,
          details: context[:request].current_organization.to_s
        )

        user_group_role_bindings = role_documents_directory.user_group_role_bindings(
            customer_crn: customer_crn,
            organization_crn: current_org_crn,
            service_account: service_account_caller?(context),
            include_role_doc_permissions: include_role_doc_permissions,
            include_role_docs: include_role_docs,
            include_role_bindings: include_role_bindings
        )

        user_group_role_bindings
      end
    end
  end
end
