# frozen_string_literal: true

require 'cht-lib-fabric/graphql/client'
require 'import'
require 'role_management/traceable'

module RoleManagement
  module Clients
    class OrgManagement < ::Platform::GraphQL::Client
      include Import['alert','logger']
      extend Traceable

      # The query file and json file are generated by a Rake task
      schema(File.expand_path('org_management.json', __dir__))
      queries(File.expand_path('org_management.graphql', __dir__))

      def get_organization(context = {})
        params = {
            "id": context[:id],
            "filter": {
                "rules": []
            }
        }
        data = query_with_retry(Queries::Organization, context, ::RoleManagement::Retry::RATE_RETRY_LIMIT, params)
        data.to_h.with_indifferent_access
      rescue => ex
        logger.error("OrgManagement Client: get_organization: #{ex.class}: #{ex.message}")
        alert.exception(ex, "OrgManagement Client: get_organization")
        nil
      end
      
      trace_method :get_organization

    end
  end
end
