# frozen_string_literal: true

require 'cht-lib-fabric/graphql/client'
require 'import'
require 'role_management/traceable'

module RoleManagement
  module Clients
    class UserManagement < ::Platform::GraphQL::Client
      include Import['alert','logger']
      extend Traceable

      # The query file and json file are generated by a Rake task
      schema(File.expand_path('user_management.json', __dir__))
      queries(File.expand_path('user_management.graphql', __dir__))

      def get_user_groups(context = {})
        params = {
            "filter": {
                "rules": []
            }
        }
        data = query_with_retry(Queries::UserGroups, context, ::RoleManagement::Retry::RATE_RETRY_LIMIT, params)
        data.to_h.with_indifferent_access
      rescue => ex
        logger.error("UserManagement Client: get_user_groups: #{ex.class}: #{ex.message}")
        alert.exception(ex, "UserManagement Client: get_user_groups")
        nil
      end

      def get_user_group(context = {})
        params = {
            "id": context[:id],
            "filterRules": [
              {
                "field": "serviceAccount",
                "filterType": "EQ",
                "filterValues": [
                  "true"
                ]
              }
            ]
        }
        data = query_with_retry(Queries::UserGroup, context,  ::RoleManagement::Retry::RATE_RETRY_LIMIT,  params)
        data.to_h.with_indifferent_access
      rescue => ex
        logger.error("UserManagement Client: get_user_group: #{ex.class}: #{ex.message}")
        alert.exception(ex, "UserManagement Client: get_user_group")
        nil
      end

      def get_service_integration_accounts(context = {})
        params = {}
        data = query_with_retry(Queries::ServiceIntegrationUsers, context,  ::RoleManagement::Retry::RATE_RETRY_LIMIT,  params)
        data.to_h.with_indifferent_access
      rescue => ex
        logger.error("UserManagement Client: get_service_integration_accounts: #{ex.class}: #{ex.message}")
        alert.exception(ex, "UserManagement Client: get_service_integration_accounts")
        nil
      end

      trace_method :get_user_groups, :get_user_group, :get_service_integration_accounts

    end
  end
end