# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/crns'
require 'role_management/consumers/application_consumer'
require 'role_management/actions'

module RoleManagement
  module Consumers
    # Consume inbound CloudHealth Organization updates
    # This action is used to help clean up role bindings when an organization
    # is deleted
    class Organizations < ApplicationConsumer
      include Import[:logger, :alert]
      def consume
        logger.debug { "processing org change message. params: #{params.to_h}" }
        if params.key?(:crn) && params.key?(:action)
          crn = ::Platform::CRNs::Organization.from_s(params['crn'])
          action = params['action'].downcase
          case action
          when 'delete'
            logger.info { "org #{crn} has been deleted. Cleaning up role management records" }
            RoleManagement::Actions::OrganizationDeleted.call!(crn: crn)
          end
        end
      rescue => ex
        alert.exception(
          ex,
          params: params.to_h,
          customer_id: (defined?(crn) && !crn.nil?) ? crn.customer : nil
        )
        raise
      end
    end
  end
end
