# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/crns'
require 'role_management/consumers/application_consumer'
require 'role_management/actions'

module RoleManagement
  module Consumers
    # Consume inbound CloudHealth UserGroup updates
    class UserGroups < ApplicationConsumer
      include Import[:logger, :alert]
      def consume
        crn = ::Platform::CRN.from_s(params['id'])
        action = params['type'].downcase
        customer_id = params['customer_id']
        organization_id = params['organization_id']
        user_id = params['user_id']

        case action
        when 'delete'
          logger.info { "user group #{crn} has been deleted. Updates user group role binding." }
          RoleManagement::Actions::UserGroupDeleted.call!(crn: crn,
                                                          customer_id: customer_id,
                                                          organization_id: organization_id,
                                                          user_id: user_id)
        end

      rescue => ex
        alert.exception(
            ex,
            params: params.to_h,
            customer_id: (defined?(crn) && !crn.nil?) ? crn.customer : nil
        )
        raise
      end
    end
  end
end
