# frozen_string_literal: true

require 'graphql'

module RoleManagement
  module GraphQL
    module Types
      module Mutations
        class CreateRoleDocument < ::GraphQL::Schema::RelayClassicMutation

          description "Creates a role document"

          argument :name, String, required: true
          argument :description, String, required: false
          argument :restricted, Boolean, required: false, default_value:false
          argument :permissions, [PermissionInput], required: false
          argument :metadata, ContentMetadataInput, "Metadata about some content", required: false

          field :id, ID, null: false
          field :name, String, null: false
          field :description, String, null: true
          field :restricted, Boolean, null: false
          field :permissions, [Permission], null: false
          field :metadata, ContentMetadata, "Metadata about some content", null: true

          def resolve(name:, description: nil, restricted:nil, permissions:nil, metadata:nil)

            role_document, metadata = RoleManagement::Actions::CreateRoleDocument.new.call(name,
                                                                          description,
                                                                          restricted,
                                                                          permissions,
                                                                          metadata,
                                                                          context)

            {
                id: role_document.id,
                name: role_document.name,
                description: role_document.description,
                restricted: role_document.restricted,
                permissions: role_document.permissions,
                metadata: metadata
            }
          end

        end
      end
    end
  end
end
