# frozen_string_literal: true

require 'graphql'

module RoleManagement
  module GraphQL
    module Types
      module Mutations
        class UpdateRoleDocument < ::GraphQL::Schema::RelayClassicMutation

          description "Updates a role document"

          argument :id, ID, required: true
          argument :name, String, required: false
          argument :description, String, required: false
          argument :permissions, [PermissionInput], "Permissions is optional but will overwrite existing if included
                                                    An empty array will wipe all permissions from the role document",
                   required: false
          argument :metadata, ContentMetadataInput, "Metadata about some content", required: false

          field :id, ID, null: false
          field :name, String, null: false
          field :description, String, null: true
          field :restricted, Boolean, null: false
          field :permissions, [Permission], null: false
          field :metadata, ContentMetadata, "Metadata about some content", null: true

          def resolve(id:, name:, description: nil, restricted:nil, permissions:nil, metadata:nil)

            result, metadata = RoleManagement::Actions::UpdateRoleDocument.new.call(id,
                                                                          name,
                                                                          description,
                                                                          restricted,
                                                                          permissions,
                                                                          metadata,
                                                                          context)

            {
                id: result.id,
                name: result.name,
                description: result.description,
                restricted: result.restricted,
                permissions: result.permissions,
                metadata: metadata
            }
          end

        end
      end
    end
  end
end
