# frozen_string_literal: true

require 'cht-lib-fabric/graphql/federation/types'

module RoleManagement
  module GraphQL
    module Types
      class RoleDocument < ::Platform::GraphQL::Types::BaseObject
        implements ::GraphQL::Relay::Node.interface

        field :id, ID, null: false
        field :organization_id, ID, null: true
        field :name, String, null: false
        field :description, String, null: true
        field :created_at, ::GraphQL::Types::ISO8601DateTime, null: false
        field :updated_at, ::GraphQL::Types::ISO8601DateTime, null: false
        field :system_defined, Boolean, null: false
        field :restricted, Boolean, null: false

        field :createdByCRN, ID, null: false
        field :updatedByCRN, ID, null: false

        field :created_by_user_id, String, null: false
        field :updated_by_user_id, String, null: false

        field :permissions, Permission.connection_type, null: true

        field :user_group_role_bindings, UserGroupRoleBinding.connection_type, null:true,

              resolve: -> (obj, _args, ctx) {
                customer_id = ctx[:request].current_customer
                customer_crn = ::Platform::CRNs::Tenant.new(customer: customer_id).to_s
                current_org_crn = ::Platform::CRNs::Organization.new(
                    customer: customer_id,
                    details: ctx[:request].current_organization.to_s
                ).to_s

                user_group_role_bindings = obj[:user_group_role_bindings].where(
                    customer_crn: customer_crn,
                    organization_crn: current_org_crn
                ).map do |urgh|
                  {
                      id: urgh.crn.to_s,
                      user_group_id: urgh.user_group_crn,
                      organization_id: urgh.organization_crn,
                      organization_ids: urgh.user_group_role_binding_organizations.map do |ou|
                        ou.organization_crn
                      end,
                      created_by_id:         urgh.created_by_crn,
                      updated_by_id:         urgh.updated_by_crn,
                      created_at:            urgh.created_at,
                      updated_at:            urgh.updated_at
                  }
                end
                user_group_role_bindings
              }


        field :metadata, ContentMetadata, null: true

        def organization_id
          unless object.organizationId.nil?
            created_by_crn = ::Platform::CRNs::User.from_s(object.created_by)
            ::Platform::CRNs::Organization.new(
                organization: object.organizationId,
                customer: created_by_crn.customer.to_i
            ).to_s
          end
        end

        def created_by_crn
          object.created_by
        end

        def updated_by_crn
          object.updated_by
        end

        def created_by_user_id
          object.created_by
        end

        def updated_by_user_id
          object.updated_by
        end

      end
    end
  end
end
