# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/dry_types'

module RoleManagement
  module Messages
    class BaseMessage
      include Import[
        :settings,
        'kafka.producers'
      ]

      CREATE = :create
      DELETE = :delete
      UPDATE = :update

      # 
      # Publish a kafka event for an object payload
      #
      # @param - payload               - The object representing the message payload
      # @param - partition_key         - The key used to partition messages
      # @param - base_topic            - The name of the kafka topic
      def send(payload, partition_key, base_topic)

        topic = if settings.kafka_topic_prefix.blank?
                then base_topic
                else "#{settings.kafka_topic_prefix}.#{base_topic}"
                end

        producers.with do |producer|
          producer.produce(payload.to_json,
                           key: partition_key,
                           topic: topic)
          begin
            producer.deliver_messages
          rescue ::Kafka::DeliveryFailed
            producer.clear_buffer
            raise
          end
        end
      end
    end
  end
end
