# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/dry_types'
require 'role_management/messages/base_message'

module RoleManagement
  module Messages
    class RoleBinding < ::RoleManagement::Messages::BaseMessage

      TOPIC = "com.cloudhealthtech.svc.role_management.role_binding_action"

      # 
      # Publish a kafka event for an role binding object
      #
      # @param - role_document   - The role binding object
      # @param - context         - The request context
      # @param - type            - The type of message, defaults to UPDATE
      def push(role_binding, context, type = ::BaseMessage::UPDATE)
        customer_id = context[:request].current_customer
        user_id = context[:request].current_user
        organization_id = context[:request].current_organization
        user_crn = ::Platform::CRN.from_s("crn:#{customer_id}:user/#{user_id}").to_s
        payload = {
          user_crn: user_crn,
          customer_crn: ::Platform::CRN.from_s("crn:#{customer_id}:tenant/#{customer_id}").to_s,
          role_binding_id: role_binding.id,
          user_group_id: role_binding.user_group_id,
          role_document_id: role_binding.role_document.id,
          organization_ids: role_binding.organization_ids,
          organization_id: ::Platform::CRN.from_s("crn:#{customer_id}:organization/#{organization_id}").to_s,
          action: type
        }

        send(payload, user_crn, TOPIC)

      end
    end
  end
end
