# frozen_string_literal: true

require 'import'
require 'cht-lib-fabric/crn'
require 'cht-lib-fabric/dry_types'
require 'role_management/messages/base_message'

module RoleManagement
  module Messages
    class RoleDocument < ::RoleManagement::Messages::BaseMessage

      TOPIC = "com.cloudhealthtech.svc.role_management.role_document_action"

      #
      # Publish a kafka event for an role document object
      #
      # @param - role_document   - The role document object
      # @param - context         - The request contex
      # @param - type            - The type of message, defaults to UPDATE
      def push(role_document, context, type = ::BaseMessage::UPDATE)
        customer_id = context[:request].current_customer
        user_id = context[:request].current_user
        organization_id = context[:request].current_organization
        user_crn = (user_id == Application[:settings].service_account) ? user_id : ::Platform::CRN.from_s("crn:#{customer_id}:user/#{user_id}").to_s # Handle db:seed:sync task
        payload = {
          user_crn: user_crn,
          customer_crn: ::Platform::CRN.from_s("crn:#{customer_id}:tenant/#{customer_id}").to_s,
          role_doc_id: role_document.id,
          permissions: role_document.permissions,
          organization_id: ::Platform::CRN.from_s("crn:#{customer_id}:organization/#{organization_id}").to_s,
          action: type
        }

        send(payload, user_crn, TOPIC)

      end
    end
  end
end