# frozen_string_literal: true

require 'cht-lib-fabric/dry_types'
require 'dry-struct'
require 'role_management/models/content/meta_data'

module RoleManagement
  module Models
    class RoleDocument < ::RoleManagement::Models::Relay::Node
      # @return [Platform::CRNs::RoleDocument]
      attribute :id, ::Platform::DryTypes::Strict::String
      attribute :organizationId, ::Platform::DryTypes::Strict::Integer.optional

      attribute :name, ::Platform::DryTypes::Strict::String
      attribute :description, ::Platform::DryTypes::Strict::String.optional
      attribute :system_defined, ::Platform::DryTypes::Strict::Bool
      attribute :restricted, ::Platform::DryTypes::Strict::Bool

      # @return user CRNs
      attribute :created_by, ::Platform::DryTypes::Strict::String
      attribute :updated_by, ::Platform::DryTypes::Strict::String

      attribute :created_at, ::Platform::DryTypes::Strict::Time
      attribute :updated_at, ::Platform::DryTypes::Strict::Time

      attribute :permissions, ::Platform::DryTypes::Strict::Array.of(Permission)

      attribute :user_group_role_bindings, ::Platform::DryTypes::Instance(::ActiveRecord::Associations::CollectionProxy).optional

      attribute :metadata, ::RoleManagement::Models::Content::Metadata
    end
  end
end
