# frozen_string_literal: true

require 'import'
require 'dry/transaction/operation'

require 'cht-lib-fabric/crns'
require 'cht-lib-fabric/contexts/request'
require 'cht-lib-fabric/helpers/wavefront'
require 'hitimes'

module RoleManagement
  module Operations
    class BuildRequestFromServiceAccount
      include ::Dry::Transaction::Operation
      include ::Platform::Helpers::Wavefront
      include Import['clients.service_acct',
                     'wavefront']

      # This operation is to be used when we need to make tenant
      # specific requests via a service account. It returns
      # a tenant scoped request object with an access token.
      def call(customer_id:, **)
        wf_time('role_management.operations.build_request_from_service_account') do
          tenant = ::Platform::CRNs::Tenant.new(customer: customer_id)
          svc_acct_request = ::Platform::Contexts::Request.new

          access_token = service_acct.get_tenant_access_token(
              tenant: tenant,
              justification: "Role Management",
              request: svc_acct_request
          )

          request = ::Platform::Contexts::Request.new
          request.current_customer = customer_id.to_i
          request.current_token = access_token

          Success(tenant_scoped_request: request)
        end
      end

    end
  end
end