# frozen_string_literal: true

require 'import'
require 'dry/transaction/operation'
require 'cht-lib-fabric/helpers/wavefront'
require 'cht-lib-fabric/helpers/graphql/raise_error'

require 'role_management/errors'
require 'hitimes'

module RoleManagement
  module Operations
    class FilterUserGroupBindings
      include ::Dry::Transaction::Operation
      include ::Platform::Helpers::GraphQL::RaiseError
      include ::Platform::Helpers::Wavefront
      include Import['logger',
                     'wavefront']

      def call(input)
        wf_time('role_management.operations.filter_user_group_bindings') do
          customer_id = input[:customer_id]
          role_document_crn = input[:role_document_crn]
          all_user_group_role_bindings = input[:all_user_group_role_bindings]

          role_document_user_group_bindings = []

          #filter user group bindings to get all user_group_role_bindings for the required role_document
          all_user_group_role_bindings.each do |user_group_role_binding|

            if (user_group_role_binding.role_document.id == role_document_crn.to_s)
              role_document_user_group_bindings << user_group_role_binding
            end
          end

          #create a set of unique user_group_id & set of unique organization_ids
          user_group_ids = Set.new
          organizations_ids = Set.new

          role_document_user_group_bindings.each do |role_document_user_group|
            user_group_ids << role_document_user_group.user_group_id
            organizations_ids << role_document_user_group.organization_id

            role_document_user_group.organization_ids.each do |organization_id|
              organizations_ids << organization_id
            end
          end

          if (role_document_user_group_bindings.count == 0)
            logger.info("FilterUserGroupBindings : No user group bindings available for role document: #{role_document_crn.to_s}")
          end

          Success(
              input.merge(
                  role_document_user_group_bindings: role_document_user_group_bindings,
                  user_group_ids: user_group_ids,
                  organizations_ids: organizations_ids
              )
          )

        end
      end

    end
  end
end