# frozen_string_literal: true

require 'dry/transaction/operation'
require 'import'
require 'cht-lib-fabric/helpers/wavefront'
require 'hitimes'

module RoleManagement
  module Operations
    class FormatSharedRoleDocument
      include ::Dry::Transaction::Operation
      include ::Platform::Helpers::Wavefront
      include Import['logger',
                     'wavefront']

      def call(input)
        wf_time('role_management.operations.format_shared_role_document') do
          customer_id = input[:customer_id]
          role_document = input[:role_document]
          role_document_user_group_bindings = input[:role_document_user_group_bindings]
          user_groups = input[:user_groups]
          organizations = input[:organizations]

          sharedUserGroupRoleBindings = Array.new

          role_document_user_group_bindings.map do |role_document_user_group_binding|
            #create SharedRoleDocumentUserGroup
            user_group_id = role_document_user_group_binding.user_group_id
            user_group_name = user_groups[user_group_id]
            sharedUserGroup = ::RoleManagement::Models::SharedRoleDocumentUserGroup.new(
                id: user_group_id,
                name: user_group_name
            )

            #create SharedRoleDocumentOrganization
            organization_id = role_document_user_group_binding.organization_id
            organization_name = organizations[organization_id]
            sharedRoleDocumentOrganization = ::RoleManagement::Models::SharedRoleDocumentOrganization.new(
                id: organization_id,
                name: organization_name
            )

            #create Array of (SharedRoleDocumentOrganization)
            sharedRoleDocumentOrganizations = Array.new
            role_document_user_group_binding.organizationIds.map do |org|

              org_name = organizations[org]
              sharedRoleDocumentOrg = ::RoleManagement::Models::SharedRoleDocumentOrganization.new(
                  id: org,
                  name: org_name
              )

              sharedRoleDocumentOrganizations << sharedRoleDocumentOrg
            end

            #create SharedUserGroupRoleBinding
            sharedUserGroupRoleBinding = ::RoleManagement::Models::SharedUserGroupRoleBinding.new(
                organization: sharedRoleDocumentOrganization,
                organizations: sharedRoleDocumentOrganizations,
                userGroup: sharedUserGroup
            )

            sharedUserGroupRoleBindings << sharedUserGroupRoleBinding
          end

          #create SharedRoleDocument
          sharedRoleDocument  = ::RoleManagement::Models::SharedRoleDocument.new(
              roleDocument: role_document,
              userGroupBindings: sharedUserGroupRoleBindings
          )
          sharedRoleDocument
        end
      end

    end
  end
end