# frozen_string_literal: true

require 'dry/transaction/operation'
require 'import'
require 'cht-lib-fabric/helpers/wavefront'
require 'hitimes'

module RoleManagement
  module Operations
    class LookupOrganizations
      include ::Dry::Transaction::Operation
      include ::Platform::Helpers::Wavefront
      include Import['logger',
                     'alert',
                     'wavefront',
                     'role_management.helpers.org_management_helper']

      def call(input)
        wf_time('role_management.operations.lookup_user_groups') do
          begin
            context_request = input[:context]
            organizations_ids = input[:organizations_ids]

            logger.debug("Fetching org details for : #{organizations_ids}")

            #creating a hash to store org name for each org id
            organizations = organizations_ids.each_with_object({}) do |organizations_id, memo|
              logger.debug("Calling org-management for organization : #{organizations_id}")

              organization = org_management_helper.get_organization(context_request, organizations_id)

              memo[organizations_id] = organization['node']['name']
            end

            Success (input.merge(organizations: organizations))

          rescue => ex
            logger.error("LookupOrganizations: lookup_organizations: #{ex.class}: #{ex.message}")
            alert.exception(ex,"LookupOrganizations: lookup_organizations: #{ex.class}: #{ex.message}")
            Failure ("Unable to get organizations for shared role document")
          end
        end
      end
    end
  end
end