# frozen_string_literal: true

require 'import'
require 'dry/transaction/operation'
require 'cht-lib-fabric/helpers/wavefront'
require 'cht-lib-fabric/helpers/graphql/raise_error'

require 'role_management/errors'
require 'hitimes'

module RoleManagement
  module Operations
    class LookupUserGroupBindings
      include ::Dry::Transaction::Operation
      include ::Platform::Helpers::GraphQL::RaiseError
      include ::Platform::Helpers::Wavefront
      include Import['logger',
                     'alert',
                     'wavefront',
                     'role_management.stores.role_documents_directory']

      def call(input)
        wf_time('role_management.operations..lookup_user_group_bindings') do
          begin
            customer_id = input[:customer_id]
            organization_id = input[:organization_id]
            role_document_id = input[:role_document_id]
            customer_crn = ::Platform::CRNs::Tenant.new(customer: customer_id).to_s

            organization_crn =  ::Platform::CRNs::Organization.from_s("crn:#{customer_id}:organization/#{organization_id}")

            all_user_group_role_bindings = role_documents_directory.user_group_role_bindings(customer_crn: customer_crn,
                organization_crn: organization_crn,
                service_account: true)

            logger.debug("LookupUserGroupBindings : fetching role document: #{role_document_id}")

            role_document = role_documents_directory.by_id_and_customer_crn(role_document_id,
                                                                            customer_crn,
                                                                            organization_id)

            return Success (
                 input.merge(
                     all_user_group_role_bindings: all_user_group_role_bindings,
                     role_document: role_document
                 )
            )

          rescue ::ActiveRecord::RecordNotFound
            raise_error ::RoleManagement::ErrorCodes::NOT_FOUND,
                        "LookupUserGroupBindings: Role document record not found"
          rescue StandardError => ex
            logger.error("LookupUserGroupBindings: lookup_user_group_bindings: #{ex.class}: #{ex.message}")
            alert.exception(ex, "LookupUserGroupBindings: lookup_user_group_bindings:")
            Failure ("Unable to get all user role bindings")
          end
        end
      end
    end
  end
end