# frozen_string_literal: true

require 'dry/transaction/operation'
require 'import'
require 'cht-lib-fabric/helpers/wavefront'
require 'hitimes'

module RoleManagement
  module Operations
    class LookupUserGroups
      include ::Dry::Transaction::Operation
      include ::Platform::Helpers::Wavefront
      include Import['logger',
                     'alert',
                     'wavefront',
                     'role_management.helpers.user_management_helper']

      def call(input)
        wf_time('role_management.operations.lookup_user_groups') do
          begin
            user_group_ids = input[:user_group_ids]

            logger.debug("Fetching user group details for : #{user_group_ids}")

            # Check to see if a service account request
            context_request = input[:tenant_scoped_request] || input[:context]

            #get all user groups for a customer
            all_user_groups = user_management_helper.get_user_groups(context_request)

            #filter and fetch the required user groups
            organization_user_groups =
                all_user_groups['userGroups']['edges'].map { |o| o['node'] }.select { |n| n['id'].in?(user_group_ids) }

            #hash to store user group name for each user group Id
            user_groups = organization_user_groups.each_with_object({}) do |organization_user_group, memo|
              memo[organization_user_group['id']] = organization_user_group['name']
            end

            Success (input.merge(user_groups: user_groups))

          rescue => ex
            logger.error("LookupUserGroups: lookup_user_groups: #{ex.class}: #{ex.message}")
            alert.exception(ex,"LookupUserGroups: lookup_user_groups: #{ex.class}: #{ex.message}")
            Failure ("Unable to get user groups for shared role document")
          end
        end
      end
    end
  end
end