# frozen_string_literal: true

require 'import'
require 'container'

module RoleManagement
  module Transactions
    class SharedRoleDocument
      include Application::Transaction

      step :prepare_input

      step :lookup_user_group_bindings,
           with: 'role_management.operations.lookup_user_group_bindings'

      step :filter_user_group_bindings,
           with: 'role_management.operations.filter_user_group_bindings'

      merge :build_request_from_service_account,
            with: 'role_management.operations.build_request_from_service_account'

      step :lookup_user_groups,
           with: 'role_management.operations.lookup_user_groups'

      step :lookup_organizations,
           with: 'role_management.operations.lookup_organizations'

      map :format_shared_role_document,
           with: 'role_management.operations.format_shared_role_document'

      private

      def prepare_input(input)
        context_request = input[:context]
        customer_id = input[:context][:request].current_customer
        organization_id = input[:context][:request].current_organization
        params = input[:arguments]
        id = params[:id]
        role_document_crn = ::Platform::CRN.from_s(id)
        role_document_id = role_document_crn.details.to_i

        Success(
            customer_id: customer_id,
            context: context_request,
            organization_id: organization_id,
            role_document_id: role_document_id,
            role_document_crn: role_document_crn
        )
      end

    end
  end
end