# frozen_string_literal: true
require 'role_management/utils/event_factory'
require 'role_management/messages/base_message'
require 'import'

module RoleManagement
  module Utils
    class EventPublish
      include Import['logger', 
                     'alert',
                     'role_management.utils.event_factory']

      # 
      # Publish a kafka event for an RMS Object
      #
      # @param - object      - The object representing the RMS role document or role binding
      # @param - context     - The request context for the event
      # @param - type        - The type of change, defaults to 'CHANGE'
      def publish(object, context, type = ::BaseMessage::UPDATE)
        # Find event type
        kafka_message = event_factory.get_event(object) unless object.nil?
        # Publish event
        kafka_message.push(object, context, type) unless kafka_message.nil?
      rescue => ex
        logger.error "Unable to publish #{type} event for #{object.class} #{ex.message}"
        alert.exception(
          ex,
          customer_id: context[:request].current_customer,
          user_id: context[:request].current_user,
          organization_id: context[:request].current_organization,
          action: type
        )
      end
    end
  end
end
